/// <reference types="bn.js" />
import { BN, Program } from "@coral-xyz/anchor";
import { Connection, PublicKey } from "@solana/web3.js";
import { Chain, Contracts, Network } from "@wormhole-foundation/sdk-connect";
import { Ntt } from "@wormhole-foundation/sdk-definitions-ntt";
import { IdlVersion, NttBindings } from "./bindings.js";
import { quoterAddresses } from "./utils.js";
export declare class NttQuoter<N extends Network, C extends Chain> {
    readonly network: N;
    readonly chain: C;
    readonly connection: Connection;
    readonly contracts: Contracts & {
        ntt?: Ntt.Contracts;
    };
    readonly idlVersion: IdlVersion;
    program: Program<NttBindings.Quoter>;
    pdas: ReturnType<typeof quoterAddresses>;
    instance: PublicKey;
    nttProgramId: PublicKey;
    constructor(network: N, chain: C, connection: Connection, contracts: Contracts & {
        ntt?: Ntt.Contracts;
    }, idlVersion?: IdlVersion);
    isRelayEnabled(destination: Chain): Promise<boolean>;
    /**
     * Estimate the cost of a relay request
     * @param chain The destination chain
     * @param gasDropoff The amount of native gas to end up with on the destination chain
     * @returns The estimated cost in lamports
     */
    quoteDeliveryPrice(chain: Chain, gasDropoff?: bigint): Promise<bigint>;
    createRequestRelayInstruction(payer: PublicKey, outboxItem: PublicKey, nttProgramId: PublicKey, chain: Chain, maxFee: BN, gasDropoff: BN): Promise<import("@solana/web3.js").TransactionInstruction>;
    getInstance(): Promise<{
        owner: PublicKey;
        assistant: PublicKey;
        feeRecipient: PublicKey;
        solPriceUsd: number;
    }>;
    getRegisteredNtt(): Promise<{
        gasCost: number;
        wormholeTransceiverIndex: number;
    }>;
    getRegisteredChain(chain: Chain): Promise<{
        paused: boolean;
        maxGasDropoffEth: number;
        basePriceUsd: number;
        nativePriceUsd: number;
        gasPriceGwei: number;
    }>;
}
//# sourceMappingURL=quoter.d.ts.map