import { Program } from "@coral-xyz/anchor";
import { Connection, Keypair, PublicKey, TransactionInstruction } from "@solana/web3.js";
import { AccountAddress, Chain, ChainAddress, ChainsConfig, Contracts, Network, TokenAddress, UnsignedTransaction } from "@wormhole-foundation/sdk-connect";
import { Ntt, WormholeNttTransceiver } from "@wormhole-foundation/sdk-definitions-ntt";
import { SolanaChains, SolanaPlatformType, SolanaTransaction, SolanaUnsignedTransaction } from "@wormhole-foundation/sdk-solana";
import { SolanaWormholeCore } from "@wormhole-foundation/sdk-solana-core";
import { TransferArgs, nttAddresses } from "./utils.js";
import { IdlVersion, NttBindings } from "./bindings.js";
import { NttQuoter } from "./quoter.js";
export declare class SolanaNtt<N extends Network, C extends SolanaChains> implements Ntt<N, C> {
    readonly network: N;
    readonly chain: C;
    readonly connection: Connection;
    readonly contracts: Contracts & {
        ntt?: Ntt.Contracts;
    };
    readonly idlVersion: IdlVersion;
    core: SolanaWormholeCore<N, C>;
    pdas: ReturnType<typeof nttAddresses>;
    program: Program<NttBindings.NativeTokenTransfer>;
    config?: NttBindings.Config;
    quoter?: NttQuoter<N, C>;
    constructor(network: N, chain: C, connection: Connection, contracts: Contracts & {
        ntt?: Ntt.Contracts;
    }, idlVersion?: IdlVersion);
    isRelayingAvailable(destination: Chain): Promise<boolean>;
    quoteDeliveryPrice(destination: Chain, options: Ntt.TransferOptions): Promise<bigint>;
    static fromRpc<N extends Network>(provider: Connection, config: ChainsConfig<N, SolanaPlatformType>): Promise<SolanaNtt<N, SolanaChains>>;
    getConfig(): Promise<NttBindings.Config>;
    getTokenDecimals(): Promise<number>;
    getCustodyAddress(): Promise<string>;
    getVersion(sender: AccountAddress<C>): Promise<string>;
    static _getVersion(programAddress: string, connection: Connection, sender?: AccountAddress<SolanaChains>): Promise<IdlVersion>;
    initialize(args: {
        payer: Keypair;
        owner: Keypair;
        chain: Chain;
        mint: PublicKey;
        outboundLimit: bigint;
        mode: "burning" | "locking";
    }): AsyncGenerator<SolanaUnsignedTransaction<N, C>, void, unknown>;
    registerTransceiver(args: {
        payer: Keypair;
        owner: Keypair;
        transceiver: PublicKey;
    }): AsyncGenerator<SolanaUnsignedTransaction<N, C>, void, unknown>;
    setWormholeTransceiverPeer(peer: ChainAddress, payer: AccountAddress<C>): AsyncGenerator<SolanaUnsignedTransaction<N, C>, void, unknown>;
    setPeer(peer: ChainAddress, tokenDecimals: number, inboundLimit: bigint, payer: AccountAddress<C>): AsyncGenerator<SolanaUnsignedTransaction<N, C>, void, unknown>;
    transfer(sender: AccountAddress<C>, amount: bigint, destination: ChainAddress, options: Ntt.TransferOptions, outboxItem?: Keypair): AsyncGenerator<UnsignedTransaction<N, C>, any, unknown>;
    private createAta;
    redeem(attestations: Ntt.Attestation[], payer: AccountAddress<C>): AsyncGenerator<SolanaUnsignedTransaction<N, C>, void, unknown>;
    getCurrentOutboundCapacity(): Promise<bigint>;
    getCurrentInboundCapacity(fromChain: Chain): Promise<bigint>;
    getIsExecuted(attestation: Ntt.Attestation): Promise<boolean>;
    getIsApproved(attestation: Ntt.Attestation): Promise<boolean>;
    completeInboundQueuedTransfer(fromChain: Chain, transceiverMessage: Ntt.Message, token: TokenAddress<C>, payer: AccountAddress<C>): AsyncGenerator<SolanaUnsignedTransaction<N, C>, void, unknown>;
    getInboundQueuedTransfer(chain: Chain, nttMessage: Ntt.Message): Promise<Ntt.InboundQueuedTransfer<C> | null>;
    createTransferLockInstruction(args: {
        transferArgs: TransferArgs;
        payer: PublicKey;
        from: PublicKey;
        fromAuthority: PublicKey;
        outboxItem: PublicKey;
        config?: NttBindings.Config;
    }): Promise<TransactionInstruction>;
    createTransferBurnInstruction(args: {
        transferArgs: TransferArgs;
        payer: PublicKey;
        from: PublicKey;
        fromAuthority: PublicKey;
        outboxItem: PublicKey;
        config?: NttBindings.Config;
    }): Promise<TransactionInstruction>;
    createReleaseOutboundInstruction(args: {
        payer: PublicKey;
        outboxItem: PublicKey;
        revertOnDelay: boolean;
    }): Promise<TransactionInstruction>;
    createReceiveWormholeMessageInstruction(payer: PublicKey, wormholeNTT: WormholeNttTransceiver.VAA): Promise<TransactionInstruction>;
    createRedeemInstruction(payer: PublicKey, wormholeNTT: WormholeNttTransceiver.VAA): Promise<TransactionInstruction>;
    createReleaseInboundMintInstruction(args: {
        payer: PublicKey;
        chain: Chain;
        nttMessage: Ntt.Message;
        revertOnDelay: boolean;
        recipient?: PublicKey;
    }): Promise<TransactionInstruction>;
    createReleaseInboundUnlockInstruction(args: {
        payer: PublicKey;
        chain: Chain;
        nttMessage: Ntt.Message;
        revertOnDelay: boolean;
        recipient?: PublicKey;
    }): Promise<TransactionInstruction>;
    custodyAccountAddress(mint: PublicKey): Promise<PublicKey>;
    createUnsignedTx(txReq: SolanaTransaction, description: string, parallelizable?: boolean): SolanaUnsignedTransaction<N, C>;
}
//# sourceMappingURL=ntt.d.ts.map